<?php
/**
 * コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2009 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: admin_nav_menuWidgetContainer.php 2266 2009-08-28 08:25:59Z fishbone $
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
require_once($gEnvManager->getCurrentWidgetDbPath() . '/nav_menuDb.php');

class admin_nav_menuWidgetContainer extends BaseAdminWidgetContainer
{
	var $db;	// DB接続オブジェクト
	var $serialNo;		// 選択中の項目のシリアル番号
	const MENU_ID = 'nav_menu';				// メニューID
	const MAIN_MENU_ID = 'main_menu';				// メインメニューID
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
		
		// DBオブジェクト作成
		$this->db = new nav_menuDb();
	}
	/**
	 * テンプレートファイルを設定
	 *
	 * _assign()でデータを埋め込むテンプレートファイルのファイル名を返す。
	 * 読み込むディレクトリは、「自ウィジェットディレクトリ/include/template」に固定。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						テンプレートファイル名。テンプレートライブラリを使用しない場合は空文字列「''」を返す。
	 */
	function _setTemplate($request, &$param)
	{	
		return 'admin_menu.tmpl.html';
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @param								なし
	 */
	function _assign($request, &$param)
	{
		$act = $request->trimValueOf('act');
		$selectedItemNo = $request->trimValueOf('no');		// 処理対象の項目番号
		$this->serialNo = $request->trimValueOf('item_selected');		// 選択項目のシリアル番号
		$userInfo = $this->gEnv->getCurrentUserInfo();
		$lang = $this->gEnv->getCurrentLanguage();
		$id = $request->trimValueOf('id');
		$name = $request->trimValueOf('item_name');
		$linkType = $request->trimValueOf('link_type_list');
		$url = $request->trimValueOf('item_url');		// URL
		$visible = ($request->trimValueOf('item_visible') == 'on') ? 1 : 0;		// チェックボックス
		$enable = ($request->trimValueOf('item_enable') == 'on') ? 1 : 0;		// チェックボックス
		$homepage = ($request->trimValueOf('item_homepage') == 'on') ? 1 : 0;		// チェックボックス
		$pageType = $request->trimValueOf('pagetype');		// ページタイプ
			
		if ($act == 'select'){		// 項目選択の場合
			if (empty($this->serialNo)){		// 新規項目追加のとき
				$id = 0;			// ID
				$name = '';		// 名前
				$linkType = 0;	// リンクタイプ
				$visible = 1;
				$enable = 1;
				$url = '';	// リンク先			
			} else {
				$ret = $this->db->getMenuBySerial($this->serialNo, $row);
				if ($ret){
					// 取得値を設定
					$id = $row['mi_id'];			// ID
					$name = $row['mi_name'];		// 名前
					$linkType = $row['mi_link_type'];	// リンクタイプ
					$visible = $row['mi_visible'];
					$enable = $row['mi_enable'];
					$this->serialNo = $row['mi_serial'];
					$url = $row['mi_link_url'];	// リンク先
				}
			}
		} else if ($act == 'deleteall'){		// メニュー項目すべて削除のとき
			$ret = $this->db->delMenuAllItem();
			if ($ret){
				$this->setGuidanceMsg('データを削除しました');
			} else {
				$this->setAppErrorMsg('データ削除に失敗しました');
			}
			$this->gPage->updateParentWindow();// 親ウィンドウを更新
		} else if ($act == 'add'){		// 項目追加の場合
			// 入力チェック
			$this->checkInput($name, '名前');

			// エラーなしの場合は、データを登録
			if ($this->getMsgCount() == 0){
				// IDを生成
				$id = $this->db->getNewMenuId();
				$ret = $this->db->addMenuItem(self::MENU_ID, $id, $lang, $name, 0, $linkType, $url, $visible, $enable, $userInfo->userId, $newSerial);
				if ($ret){
					$this->setGuidanceMsg('データを追加しました');
					$this->serialNo = $newSerial;		// シリアル番号を更新
				} else {
					$this->setAppErrorMsg('データ追加に失敗しました');
				}
				$this->gPage->updateParentWindow();// 親ウィンドウを更新
			}
		} else if ($act == 'update'){		// 項目更新の場合
			// 入力チェック
			$this->checkSingleByte($id, 'ID');
			$this->checkInput($name, '名前');
			
			// IDの存在チェック
			$ret = $this->db->isExistsMenuId($id, $lang);
			if (!$ret){
				$this->setUserErrorMsg('指定したIDの項目が見つかりません');
			}
			// エラーなしの場合は、データを更新
			if ($this->getMsgCount() == 0){
				$ret = $this->db->updateMenuItem(self::MENU_ID, $id, $lang, $name, 0, $linkType, $url, $visible, $enable, $userInfo->userId);
				if ($ret){
					$this->setGuidanceMsg('データを更新しました');
				} else {
					$this->setAppErrorMsg('データ更新に失敗しました');
				}
				$this->gPage->updateParentWindow();// 親ウィンドウを更新
			}				
		} else if ($act == 'delete'){		// 項目削除の場合
			if (empty($this->serialNo)){
				$this->setUserErrorMsg('削除項目が選択されていません');
			}
			// エラーなしの場合は、データを削除
			if ($this->getMsgCount() == 0){
				$ret = $this->db->delMenuItem($this->serialNo);
				if ($ret){		// データ削除成功のとき
					$this->setGuidanceMsg('データを削除しました');
				} else {
					$this->setAppErrorMsg('データ削除に失敗しました');
				}
				$this->gPage->updateParentWindow();// 親ウィンドウを更新
			}
		} else if ($act == 'updatemenu'){		// メニュー項目順の更新のとき
			$menuitems = $request->trimValueOf('menuitems');
			if (!empty($menuitems)){
				$menuItemNoArray = explode(',', $menuitems);
			
				// メニューの並び順を変更
				$this->db->orderMenuItems(self::MENU_ID, $lang, $menuItemNoArray);
			}
			$this->gPage->updateParentWindow();// 親ウィンドウを更新
		} else if ($act == 'getmainmenu'){		// メインメニューからデータを取得
			$this->db->getMainMenuItems(self::MENU_ID, self::MAIN_MENU_ID, $lang);
			$this->gPage->updateParentWindow();// 親ウィンドウを更新
		} else {			// 初期表示
			$id = 0;			// ID
			$name = '';		// 名前
			$linkType = 0;	// リンクタイプ
			$visible = 1;
			$enable = 1;
			$url = '';	// リンク先
		}
		
		// ### 入力値を再設定 ###
		$this->tmpl->addVar("_widget", "sel_item_name", $name);		// 名前
		$this->tmpl->addVar("_widget", "sel_item_url", $url);		// URL
		$this->tmpl->addVar("_widget", "home_macro", M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END);		// ホーム位置マクロ
		
		// リンクタイプ
		switch ($linkType){
			case 0:			// 同ウィンドウで開くリンク
				$this->tmpl->addVar("_widget", "link_type_0", 'selected');
				break;
			case 1:			// 別ウィンドウで開くリンク
				$this->tmpl->addVar("_widget", "link_type_1", 'selected');
				break;
		}
		// 項目表示、項目利用可否チェックボックス
		$visibleStr = '';
		if ($visible){
			$visibleStr = 'checked';
		}
		$enableStr = '';
		if ($enable){
			$enableStr = 'checked';
		}
		$this->tmpl->addVar("_widget", "sel_item_visible", $visibleStr);
		$this->tmpl->addVar("_widget", "sel_item_enable", $enableStr);
		$checked = '';
		if ($homepage){
			$checked = 'checked';
		}
		$this->tmpl->addVar("_widget", "sel_item_homepage", $checked);
		
		// 選択中のシリアル番号、IDを設定
		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
		$this->tmpl->addVar("_widget", "id", $id);
		
		// メニュー項目を取得
		$menuId = self::MENU_ID;
		$lang = $this->gEnv->getCurrentLanguage();
		$this->db->getAllMenuItems(array($this, 'itemListLoop'), $menuId, $lang);
		
		// ウィジェットメインIDメニュー作成
		$this->db->getPageIdList(array($this, 'pageIdLoop'), 0);
		
		// ウィジェットサブIDメニュー作成
		$this->db->getPageIdList(array($this, 'pageSubIdLoop'), 1);
		
		/*
		if (empty($pageType) || $pageType == 'top'){
			$this->tmpl->addVar("_widget", "selected_top", 'selected');		// トップページ
		} else {
			$this->tmpl->addVar("_widget", "selected_other", 'selected');		// トップページ以外
			$this->tmpl->setAttribute('otherpage', 'visibility', 'visible');// ページID,ページサブID選択メニューを表示
		}*/
			
		// ボタンの表示制御
		if (empty($this->serialNo)){		// 新規追加項目を選択しているとき
			$this->tmpl->addVar("_widget", "new_selected", 'checked');// 新規追加をチェック状態にする
			
			$this->tmpl->setAttribute('add_button', 'visibility', 'visible');// 「新規追加」ボタン
		} else {
			$this->tmpl->setAttribute('del_button', 'visibility', 'visible');// 「削除」ボタン
		}
	}
	/**
	 * 取得したデータをテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function itemListLoop($index, $fetchedRow, $param)
	{
		static $rowno = 0;
		
		$visible = '';
		if ($fetchedRow['mi_visible']){
			$visible = 'checked';
		}
		$enable = '';
		if ($fetchedRow['mi_enable']){
			$enable = 'checked';
		}
		// リンクタイプ
		$linkString = '';
		switch ($fetchedRow['mi_link_type']){
			case 0:			// 同ウィンドウで開くリンク
				$linkString = '同ウィンドウ';
				break;
			case 1:			// 別ウィンドウで開くリンク
				$linkString = '別ウィンドウ';
				break;
		}
		// 項目選択のラジオボタンの状態
		$serial = $this->convertToDispString($fetchedRow['mi_serial']);
		$selected = '';
		if ($serial == $this->serialNo){
			$selected = 'checked';
		}
		$row = array(
			'no' => $index + 1,													// 行番号
			'rowno' => $rowno,													// 行番号
			'serial' => $serial,			// シリアル番号
			'id' => $this->convertToDispString($fetchedRow['mi_id']),			// ID
			'name' => $this->convertToDispString($fetchedRow['mi_name']),		// 名前
			'index' => $this->convertToDispString($fetchedRow['mi_index']),		// インデックス
			'link_type' => $linkString,											// リンクタイプ
			'link_str' => $this->convertToDispString($fetchedRow['mi_link_url']),		// リンクURL
			'update_dt' => $this->convertToDispDateTime($fetchedRow['mi_create_dt']),	// 更新日時
			'visible' => $visible,											// メニュー項目表示制御
			'enable' => $enable,												// メニュー項目利用制御
			'selected' => $selected												// 項目選択用ラジオボタン
		);
		$this->tmpl->addVars('itemlist', $row);
		$this->tmpl->parseTemplate('itemlist', 'a');
		
		// メニューのプレビュー
		if ($fetchedRow['mi_visible']){		// 表示項目のみ追加
			$this->tmpl->addVars('menuitemlist', $row);
			$this->tmpl->parseTemplate('menuitemlist', 'a');
			$rowno++;
		}
		return true;
	}
	/**
	 * ページID、取得したデータをテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function pageIdLoop($index, $fetchedRow, $param)
	{
		$selected = '';
		$row = array(
			'value'    => $this->convertToDispString($fetchedRow['pg_id']),			// ページID
			'name'     => $this->convertToDispString($fetchedRow['pg_name']),			// ページ名
			'selected' => $selected														// 選択中かどうか
		);
		$this->tmpl->addVars('main_id_list', $row);
		$this->tmpl->parseTemplate('main_id_list', 'a');
		return true;
	}
	/**
	 * ページサブID、取得したデータをテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function pageSubIdLoop($index, $fetchedRow, $param)
	{
		$selected = '';
		$row = array(
			'value'    => $this->convertToDispString($fetchedRow['pg_id']),			// ページID
			'name'     => $this->convertToDispString($fetchedRow['pg_name']),			// ページ名
			'selected' => $selected														// 選択中かどうか
		);
		$this->tmpl->addVars('sub_id_list', $row);
		$this->tmpl->parseTemplate('sub_id_list', 'a');
		return true;
	}
}
?>
